==> chaotic_helper-3.0.0.tar.gz: lib/init/files_templates.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps

part of init;

String get _analysisOptionsTemp {
  return '''
include: package:flutter_lints/flutter.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false
    prefer_relative_imports: true

analyzer:
  errors:
    unused_import: warning
    prefer_relative_imports: error

  strong-mode:
    implicit-casts: true
''';
}

String get _helperTemp {
  return '''
import 'package:chaotic/commons.dart';
import 'package:easy_logger/easy_logger.dart';
import 'package:flutter/material.dart';

/// dan't use [print()] function
/// you must use [logger] object any time you need to print something in console
/// all logger messages will be shown if and only if application is running on debug mode
final logger = EasyLogger(
  name: 'Your Application Name ',
  enableBuildModes: [BuildMode.debug],
  enableLevels: LevelMessages.values,
  printer: (
    Object object, {
    LevelMessages? level,
    String? name,
    StackTrace? stackTrace,
  }) {
    _printFullText(
      StringBuffer()
        ..write(
          '[\$name\${_loggerIcon(level)}] '
          '[\${enumToString(level).toUpperCase()}] '
          '\$object',
        ),
      name,
      level,
    );
  },
);

/// this function will print first [_maxPrintingCharacters] characters in console
void _printFullText(StringBuffer buffer, String? name, LevelMessages? level) {
  final matches = RegExp('.{1,800}').allMatches(buffer.toString());
  final coloredText = _comprizable(level);
  for (var i = 0; i < matches.length; i++) {
    debugPrint(coloredText(matches.elementAt(i).group(0) ?? ''));
  }
}

/// this function will return a => function that accept a string and return coloredString
/// color will based on [LevelMessage]
String Function(String) _comprizable(LevelMessages? level) {
  switch (level) {
    case LevelMessages.debug:
      // gray
      return (str) => '\\u001b[90m\$str\\u001b[0m';
    case LevelMessages.info:
      // green
      return (str) => '\\u001b[32m\$str\\u001b[0m';
    case LevelMessages.warning:
      // blue
      return (str) => '\\u001B[34m\$str\\u001b[0m';
    case LevelMessages.error:
      // red
      return (str) => '\\u001b[31m\$str\\u001b[0m';
    default:
      // gray
      return (str) => '\\u001b[90m\$str\\u001b[0m';
  }
}

/// just returning an logger icon base on level message
String _loggerIcon(LevelMessages? level) {
  switch (level) {
    case LevelMessages.debug:
      return '🧪';
    case LevelMessages.info:
      return '💡';
    case LevelMessages.warning:
      return '🤔';
    case LevelMessages.error:
      return '👎';
    default:
      return '😀';
  }
}
''';
}

final _packagesTemp = [
  Packages.bot_toast,
  Packages.provider,
  Packages.easy_localization,
  Packages.easy_logger,
  Packages.chaotic,
  Packages.go_router,
];

String get _assetsTemp {
  return '''
  
  assets:
    - assets/lang/
''';
}

String get _mainTemp {
  return '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:provider/provider.dart';
import 'package:chaotic/services.dart';
import 'package:flutter/material.dart';

import 'src/service/router.dart';


Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();

  Provider.debugCheckInvalidValueType = null;
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: const MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp.router(
        routeInformationParser: RouterService.getInstance().parser,
        routerDelegate: RouterService.getInstance().delegate,
        scaffoldMessengerKey: ContextService.scaffoldKey,
        builder: BotToastInit(),
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
    );
  }
}''';
}

String get _arTemp {
  return '''
{}''';
}

String get _enTemp {
  return '''
{}''';
}

String _screenTemp(String screenName) {
  final screenNameCamelCase = screenName.toCamelCase();
  return '''
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:go_router/go_router.dart';


import '${screenName}_provider.dart';
export '${screenName}_provider.dart';

class ${screenNameCamelCase}Screen extends StatefulWidget {
  static String path = '/$screenName';
  static String name = '$screenName';

  static Widget routeBuilder(BuildContext ctx, GoRouterState state) {
    return ChangeNotifierProvider(
      create: (_) => ${screenNameCamelCase}Provider(),
      child: const ${screenNameCamelCase}Screen(),
    );
  }
  const ${screenNameCamelCase}Screen({Key? key}) : super(key: key);

  @override
  State<${screenNameCamelCase}Screen> createState() => _${screenNameCamelCase}ScreenState();
}

class _${screenNameCamelCase}ScreenState extends State<${screenNameCamelCase}Screen> {
  late ${screenNameCamelCase}Provider provider;

  @override
  Widget build(BuildContext context) {
    provider = context.watch<${screenNameCamelCase}Provider>()..ctx = context;
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelCase screen')),
    );
  }
}''';
}

String _providerTemp(String providerName) {
  final providerNameCamelCase = providerName.toCamelCase();
  return '''
import 'package:flutter/material.dart';

class ${providerNameCamelCase}Provider extends ChangeNotifier{
  BuildContext? _ctx;
  set ctx(BuildContext value) => _ctx = value;
}''';
}

String _widgetTemp(String widgetName) {
  final widgetNameCamelCase = widgetName.toCamelCase();
  return '''
import 'package:flutter/material.dart';

class $widgetNameCamelCase extends StatelessWidget {

  const $widgetNameCamelCase ({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetNameCamelCase widget'),
    );
  }
}''';
}

String _modelTemp(String modelName) {
  final modelNameCamelCase = modelName.toCamelCase();
  return '''
extension ${modelNameCamelCase.toCamelCase()}Methods on ${modelNameCamelCase.toCamelCase()}{}
class ${modelNameCamelCase.toCamelCase()}{}''';
}

String _serviceTemp(String serviceName) {
  final serviceNameCamelCase = serviceName.toCamelCase();
  return '''
class ${serviceNameCamelCase}Service {
  ${serviceNameCamelCase}Service._();
  static final _instance = ${serviceNameCamelCase}Service._();
  factory ${serviceNameCamelCase}Service.getInstance() => _instance;
  //--------------------
}''';
}

String _repositoryTemp(String repositoryName) {
  final repositoryNameCamelCase = repositoryName.toCamelCase();
  return '''
class ${repositoryNameCamelCase}Repository {}''';
}

String _clearTemp() {
  return '''
import 'package:chaotic_helper/init.dart';

Future<void> main() async {
  
  await Chaotic.clear();
}''';
}

String _fullRoutesGeneratedTemp(String screenName) {
  StringBuffer routes = StringBuffer();
  StringBuffer imports = StringBuffer();
  for (final screen in _screenFolder.listSync()) {
    final name = screen.path.split('\\').last;
    final nameCamelCase = name.toCamelCase();
    routes.writeln('''GoRoute(
      name: ${nameCamelCase}Screen.name,
      path: ${nameCamelCase}Screen.path,
      builder: ${nameCamelCase}Screen.routeBuilder,
    ),'''
        .trim());
    imports.writeln('''import '../screen/$name/$name.dart';'''.trim());
  }
  return '''
import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';

${imports.toString()}

class RouterService {
  RouterService._();
  static final _instance = RouterService._();
  factory RouterService.getInstance() => _instance;
  //--------------------
  final _routes = <GoRoute>[
    ${routes.toString()}
  ];

  late final _router = GoRouter(
    initialLocation: '/$screenName',
    debugLogDiagnostics: true,
    urlPathStrategy: UrlPathStrategy.path,
    routes: _routes,
  );
  RouteInformationParser<Object> get parser => _router.routeInformationParser;
  RouterDelegate<Object> get delegate => _router.routerDelegate;
}
'''
          .trim() +
      '\n';
}

String _addNewRouteTemp(String screenName) {
  final routerFile = _getFile('router.dart', _serviceFolder);
  final str = routerFile.readAsStringSync();
  final nameCamelCase = screenName.toCamelCase();
  return str
      .replaceFirst(
          'final _routes = <GoRoute>[',
          '''final _routes = <GoRoute>[\nGoRoute(
      name: ${nameCamelCase}Screen.name,
      path: ${nameCamelCase}Screen.path,
      builder: ${nameCamelCase}Screen.routeBuilder,
    ),'''
              .trim())
      .replaceFirst(
        'class RouterService {',
        '''import '../screen/$screenName/$screenName.dart';\nclass RouterService {'''
            .trim(),
      );
}

==> chaotic_helper-3.2.1.tar.gz: lib/init/files_templates.dart <==
part of init;

String get _analysisOptionsTemp {
  return '''
include: package:flutter_lints/flutter.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false
    prefer_relative_imports: true

analyzer:
  errors:
    unused_import: warning
    prefer_relative_imports: error

  strong-mode:
    implicit-casts: true
''';
}

String get _helperTemp {
  return '''
import 'package:chaotic/commons.dart';
import 'package:easy_logger/easy_logger.dart';
import 'package:flutter/material.dart';

/// dan't use [print()] function
/// you must use [logger] object any time you need to print something in console
/// all logger messages will be shown if and only if application is running on debug mode
final logger = EasyLogger(
  name: 'Your Application Name ',
  enableBuildModes: [BuildMode.debug],
  enableLevels: LevelMessages.values,
  printer: (
    Object object, {
    LevelMessages? level,
    String? name,
    StackTrace? stackTrace,
  }) {
    _printFullText(
      StringBuffer()
        ..write(
          '[\$name\${_loggerIcon(level)}] '
          '[\${enumToString(level).toUpperCase()}] '
          '\$object',
        ),
      name,
      level,
    );
  },
);

/// this function will print first [_maxPrintingCharacters] characters in console
void _printFullText(StringBuffer buffer, String? name, LevelMessages? level) {
  final matches = RegExp('.{1,800}').allMatches(buffer.toString());
  final coloredText = _comprizable(level);
  for (var i = 0; i < matches.length; i++) {
    debugPrint(coloredText(matches.elementAt(i).group(0) ?? ''));
  }
}

/// this function will return a => function that accept a string and return coloredString
/// color will based on [LevelMessage]
String Function(String) _comprizable(LevelMessages? level) {
  switch (level) {
    case LevelMessages.debug:
      // gray
      return (str) => '\\u001b[90m\$str\\u001b[0m';
    case LevelMessages.info:
      // green
      return (str) => '\\u001b[32m\$str\\u001b[0m';
    case LevelMessages.warning:
      // blue
      return (str) => '\\u001B[34m\$str\\u001b[0m';
    case LevelMessages.error:
      // red
      return (str) => '\\u001b[31m\$str\\u001b[0m';
    default:
      // gray
      return (str) => '\\u001b[90m\$str\\u001b[0m';
  }
}

/// just returning an logger icon base on level message
String _loggerIcon(LevelMessages? level) {
  switch (level) {
    case LevelMessages.debug:
      return '🧪';
    case LevelMessages.info:
      return '💡';
    case LevelMessages.warning:
      return '🤔';
    case LevelMessages.error:
      return '👎';
    default:
      return '😀';
  }
}
''';
}

final _packagesTemp = [
  Packages.bot_toast,
  Packages.provider,
  Packages.easy_localization,
  Packages.easy_logger,
  Packages.chaotic,
  Packages.go_router,
];

String get _assetsTemp {
  return '''
  
  assets:
    - assets/lang/
''';
}

String get _mainTemp {
  return '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:provider/provider.dart';
import 'package:chaotic/services.dart';
import 'package:flutter/material.dart';

import 'src/service/router.dart';


Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();

  Provider.debugCheckInvalidValueType = null;
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: const MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp.router(
        routeInformationParser: RouterService.getInstance().parser,
        routerDelegate: RouterService.getInstance().delegate,
        scaffoldMessengerKey: ContextService.scaffoldKey,
        builder: BotToastInit(),
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
    );
  }
}''';
}

String get _arTemp {
  return '''
{}''';
}

String get _enTemp {
  return '''
{}''';
}

String _screenTemp(String screenName) {
  final screenNameCamelCase = screenName.toCamelCase();
  return '''
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '${screenName}_provider.dart';
export '${screenName}_provider.dart';

class ${screenNameCamelCase}Screen extends StatefulWidget {
  const ${screenNameCamelCase}Screen({Key? key}) : super(key: key);

  @override
  State<${screenNameCamelCase}Screen> createState() => _${screenNameCamelCase}ScreenState();
}

class _${screenNameCamelCase}ScreenState extends State<${screenNameCamelCase}Screen> {
  late ${screenNameCamelCase}Provider provider;

  @override
  Widget build(BuildContext context) {
    provider = context.watch<${screenNameCamelCase}Provider>()..ctx = context;
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelCase screen')),
    );
  }
}''';
}

String _providerTemp(String providerName) {
  final providerNameCamelCase = providerName.toCamelCase();
  return '''
import 'package:flutter/material.dart';

class ${providerNameCamelCase}Provider extends ChangeNotifier{
  BuildContext? ctx;
}''';
}

String _widgetTemp(String widgetName) {
  final widgetNameCamelCase = widgetName.toCamelCase();
  return '''
import 'package:flutter/material.dart';

class $widgetNameCamelCase extends StatelessWidget {

  const $widgetNameCamelCase ({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetNameCamelCase widget'),
    );
  }
}''';
}

String _modelTemp(String modelName) {
  final modelNameCamelCase = modelName.toCamelCase();
  return '''
extension ${modelNameCamelCase.toCamelCase()}Methods on ${modelNameCamelCase.toCamelCase()}{}
class ${modelNameCamelCase.toCamelCase()}{}''';
}

String _serviceTemp(String serviceName) {
  final serviceNameCamelCase = serviceName.toCamelCase();
  return '''
class ${serviceNameCamelCase}Service {
  ${serviceNameCamelCase}Service._();
  static final _instance = ${serviceNameCamelCase}Service._();
  factory ${serviceNameCamelCase}Service.getInstance() => _instance;
  //--------------------
}''';
}

String _repositoryTemp(String repositoryName) {
  final repositoryNameCamelCase = repositoryName.toCamelCase();
  return '''
class ${repositoryNameCamelCase}Repository {}''';
}

String _clearTemp() {
  return '''
import 'package:chaotic_helper/init.dart';

Future<void> main() async {
  
  await Chaotic.clear();
}''';
}

String _routerTemp(String screenName) {
  return '''
import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:provider/provider.dart';

class RouterService {
  RouterService._();
  static final _instance = RouterService._();
  factory RouterService.getInstance() => _instance;
  //--------------------
  
  // /// path /fullPath
  // static String name = UniqueKey().toString();

  final _routes = <GoRoute>[
    // GoRoute(
    //   name: name,
    //   path: 'fullPath',
    //   builder: (_, __) {
    //     return ChangeNotifierProvider(
    //       create: (_) => toProvider(),
    //       child: const toScreen(),
    //     );
    //   },
    // ),
  ];

  late final _router = GoRouter(
    initialLocation: '/',
    debugLogDiagnostics: true,
    urlPathStrategy: UrlPathStrategy.path,
    routes: _routes,
  );
  RouteInformationParser<Object> get parser => _router.routeInformationParser;
  RouterDelegate<Object> get delegate => _router.routerDelegate;
}
'''
          .trim() +
      '\n';
}
